@@ -20,16 +20,19 @@
 
 ##' Evaluate a Spline Basis
 ##'
-##' Evaluate a predefined spline basis at given values.
+##' This function evaluates a predefined spline basis at (new) given values.
 ##'
 ##' These are methods for the generic function \code{predict} for objects
-##' inheriting from class \code{\link{ibs}}, \code{\link{mSpline}}, or
-##' \code{\link{iSpline}}. If \code{newx} is not given, the function returns
-##' the input object.
+##' inheriting from class \code{bSpline2}, \code{ibs}, \code{mSpline},
+##' \code{iSpline}, or \code{cSpline}.  If \code{newx} is not given, the
+##' function returns the input object.  For object returned by function
+##' \code{\link{cSpline}}, the \code{mSpline} and \code{iSpline} objects shipped
+##' in attributes should not be evaluated by this function if \code{rescale} is
+##' \code{TRUE}.  See \code{\link{cSpline}} for details.
 ##'
 ##' @name predict
-##' @param object Objects of class \code{\link{ibs}}, \code{\link{mSpline}}, or
-##' \code{\link{iSpline}} having attributes describing \code{knots},
+##' @param object Objects of class \code{bSpline2}, \code{ibs}, \code{mSpline},
+##' \code{iSpline}, or \code{cSpline} having attributes describing \code{knots},
 ##' \code{degree}, etc.
 ##' @param newx The \code{x} values at which evaluations are required.
 ##' @param ... Optional argument for future usage.
@@ -42,6 +45,10 @@
 ##' knots <- c(0.3, 0.5, 0.6)
 ##' newX <- seq(0.1, 0.9, 0.2)
 ##'
+##' ## for B-spline
+##' bsMat <- bSpline(x, knots = knots, degree = 2)
+##' predict(bsMat, newX)
+##'
 ##' ## for integral of B-spline
 ##' ibsMat <- ibs(x, knots = knots, degree = 2)
 ##' predict(ibsMat, newX)
@@ -51,25 +58,40 @@
 ##' predict(msMat, newX)
 ##'
 ##' ## for I-spline
-##' imsMat <- iSpline(x, knots = knots, degree = 2)
-##' predict(imsMat, newX)
+##' isMat <- iSpline(x, knots = knots, degree = 2)
+##' predict(isMat, newX)
 ##'
+##' ## for C-spline
+##' csMat <- cSpline(x, knots = knots, degree = 2)
+##' predict(csMat, newX)
 ##' @seealso
+##' \code{\link{bSpline}} for B-spline basis;
 ##' \code{\link{ibs}} for integral of B-spline basis;
 ##' \code{\link{mSpline}} for M-spline basis;
-##' \code{\link{iSpline}} for I-spline basis.
-##'
+##' \code{\link{iSpline}} for I-spline basis;
+##' \code{\link{cSpline}} for C-spline basis.
 ##' @importFrom stats predict
 NULL
 
 
+##' @rdname predict
+##' @export
+predict.bSpline2 <- function(object, newx, ...) {
+    if (missing(newx)) return(object)
+    a <- c(list(x = newx),
+           attributes(object)[c("degree", "knots", "Boundary.knots",
+                                "intercept")])
+    do.call("bSpline", a)
+}
+
+
 ##' @rdname predict
 ##' @export
 predict.ibs <- function(object, newx, ...) {
     if (missing(newx)) return(object)
     a <- c(list(x = newx),
-          attributes(object)[c("degree", "knots", "Boundary.knots",
-                               "intercept")])
+           attributes(object)[c("degree", "knots", "Boundary.knots",
+                                "intercept")])
     do.call("ibs", a)
 }
 
@@ -79,8 +101,8 @@ predict.ibs <- function(object, newx, ...) {
 predict.mSpline <- function(object, newx, ...) {
     if (missing(newx)) return(object)
     a <- c(list(x = newx),
-          attributes(object)[c("degree", "knots", "Boundary.knots",
-                               "intercept")])
+           attributes(object)[c("degree", "knots", "Boundary.knots",
+                                "intercept")])
     do.call("mSpline", a)
 }
 
@@ -90,7 +112,18 @@ predict.mSpline <- function(object, newx, ...) {
 predict.iSpline <- function(object, newx, ...) {
     if (missing(newx)) return(object)
     a <- c(list(x = newx),
-          attributes(object)[c("degree", "knots", "Boundary.knots",
-                               "intercept")])
+           attributes(object)[c("degree", "knots", "Boundary.knots",
+                                "intercept")])
     do.call("iSpline", a)
 }
+
+
+##' @rdname predict
+##' @export
+predict.cSpline <- function(object, newx, ...) {
+    if (missing(newx)) return(object)
+    a <- c(list(x = newx),
+           attributes(object)[c("degree", "knots", "Boundary.knots",
+                                "intercept")])
+    do.call("cSpline", a)
+}
